# robotcode-utils

[![PyPI - Version](https://img.shields.io/pypi/v/robotcode-utils.svg)](https://pypi.org/project/robotcode-utils)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/robotcode-utils.svg)](https://pypi.org/project/robotcode-utils)

-----

## Introduction

The [RobotCode](https://robotcode.io) Debugger for Robot Framework.

## Installation

```console
pip install robotcode-debugger
```

## License

`robotcode-utils` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.
